@@ -1,5 +1,5 @@
 // -*-c++-*-
-/* $Id: rpctypes.h,v 1.11 2005/11/22 17:42:29 max Exp $ */
+/* $Id: rpctypes.h 3713 2008-10-10 06:31:41Z max $ */
 
 /*
  *
@@ -31,19 +31,20 @@
 #include "union.h"
 #include "keyfunc.h"
 #include "err.h"
+#include "qhash.h"
 
 struct rpcgen_table {
   const char *name;
 
   const std::type_info *type_arg;
   void *(*alloc_arg) ();
-  xdrproc_t xdr_arg;
+  sfs::xdrproc_t xdr_arg;
   void (*print_arg) (const void *, const strbuf *, int,
 		     const char *, const char *);
 
   const std::type_info *type_res;
   void *(*alloc_res) ();
-  xdrproc_t xdr_res;
+  sfs::xdrproc_t xdr_res;
   void (*print_res) (const void *, const strbuf *, int,
 		     const char *, const char *);
 };
@@ -54,6 +55,7 @@ struct rpc_program {
   const struct rpcgen_table *tbl;
   size_t nproc;
   const char *name;
+  bool lookup (const char *rpc, u_int32_t *out) const;
 };
 
 enum { RPC_INFINITY = 0x7fffffff };
@@ -271,9 +273,13 @@ template<size_t n = RPC_INFINITY> struct rpc_bytes : rpc_vec<char, n> {
   using rpc_vec<char, n>::base;
   using rpc_vec<char, n>::size;
 
-  void setstrmem (const str &s) { set (s.cstr (), s.len ()); }
-  rpc_bytes &operator= (const str &s)
-    { setsize (s.len ()); memcpy (base (), s.cstr (), size ()); return *this; }
+  void setstrmem (const str &s) { rpc_vec<char,n>::set (s.cstr (), s.len ()); }
+  rpc_bytes &operator= (const str &s) 
+  { 
+    rpc_vec<char,n>::setsize (s.len ()); 
+    memcpy (base (), s.cstr (), size ()); 
+    return *this; 
+  }
   template<size_t m> rpc_bytes &operator= (const rpc_vec<char, m> &v)
     { rpc_vec<char, n>::operator= (v); return *this; }
   template<size_t m> rpc_bytes &operator= (const array<char, m> &v)
