@@ -1,5 +1,5 @@
 // -*-c++-*-
-/* $Id: refcnt.h,v 1.12 2005/11/01 16:20:33 max Exp $ */
+/* $Id: refcnt.h 3758 2008-11-13 00:36:00Z max $ */
 
 /*
  *
@@ -181,7 +181,7 @@ protected:
     if (!--refcount_cnt)
       refcount_call_finalize ();
   }
-  u_int refcount_getcnt () { return refcount_cnt; }
+  u_int refcount_getcnt () const { return refcount_cnt; }
 };
 
 class refpriv {
@@ -374,7 +374,7 @@ public:
   static rc_t *alloc (size_t n)
     { return new (opnew (n + (size_t) tptr (NULL))) rc_t; }
   static T *tptr (rc_t *rcp)
-    { return (T *) ((char *) rcp + (sizeof (*rcp) + 7 & ~7)); }
+    { return (T *) ((char *) rcp + ((sizeof (*rcp) + 7) & ~7)); }
 };
 
 #define REFOPS_DEFAULT(T)			\
@@ -404,12 +404,15 @@ public:
   void *get () const { return p; }
 };
 
+template<class T> class mkcref;
+
 template<class T>
 class ref : public refpriv, public refops<T> {
   friend class refpriv;
   using refops<T>::p;
 
   friend ref<T> mkref<T> (T *);
+  friend class mkcref<T>;
   ref (T *pp, refcount *cc) : refpriv (cc) { p = pp; inc (); }
 
   void inc () const { rinc (c); }
@@ -417,7 +420,7 @@ class ref : public refpriv, public refops<T> {
 
 public:
   typedef T type;
-  typedef ptr<T> ptr;
+  typedef struct ptr<T> ptr;
 
   template<class U, reftype v>
   ref (refcounted<U, v> *pp)
@@ -479,7 +482,7 @@ class ptr : public refpriv, public refops <T> {
 
 public:
   typedef T type;
-  typedef ref<T> ref;
+  typedef struct ref<T> ref;
 
   explicit ptr (__bss_init) {}
   ptr () : refpriv (NULL) { p = NULL; }
@@ -529,4 +532,19 @@ mkref (T *p)
   return ref<T> (p, p);
 }
 
+template<class T>
+struct mkcref {
+  static ref<T> mkref (T *p)
+  {
+    return ref<T> (p, const_cast<refcount *> (static_cast<const refcount *> (p)));
+  }
+};
+
+template<class T> ref<const T>
+mkref (const T *p)
+{
+  return mkcref<const T>::mkref (p);
+}
+
+
 #endif /* !_REFCNT_H_INCLUDED_ */
