@@ -1,5 +1,5 @@
 // -*-c++-*-
-/* $Id: agentmisc.h,v 1.2 2004/01/15 16:45:22 max Exp $ */
+/* $Id: agentmisc.h 1754 2006-05-19 20:59:19Z max $ */
 
 /*
  *
@@ -32,6 +32,8 @@ extern str dotsfs;
 extern str agentsock;
 extern str userkeysdir;
 
+str agent_userdir (u_int32_t uid, bool create);
+str agent_usersock (bool create_dir = false);
 void agent_setsock ();
 void agent_ckdir (bool fail_on_keysdir = true);
 bool agent_ckdir (const str &dir);
